@@ -15,9 +15,19 @@ class Thread:
         self.id = str(uuid4())
 
     def __len__(self):
-        """ Returns the length of the thread """
+        """ Returns the length of the Thread, by message count """
+
         return len(self.thread)
 
+    def __getitem__(self, index):
+        if type(index) not in (int, slice):
+            raise TypeError("list indices must be integers or slices, not %s" % type(index))
+
+        return self.thread[index]
+
+    def __setitem__(self, index, value):
+        self.thread[index] = value
+
     def serialize(self):
         """ Returns a serializable, JSON-friendly dict with all of the
         thread's data. Can be restored to a new Thread object later. """
@@ -46,8 +56,8 @@ class Thread:
             if not message.sticky or include_sticky:
                 self.thread.remove(message)
 
-    def feed(self, *messages):
-        """ Appends a new message to the thread feed. """
+    def feed(self, *messages, insert=None):
+        """ Appends a new message to the Thread feed. """
 
         try:
             # Check if the first argument is a list, and then make it the parent
@@ -77,21 +87,38 @@ class Thread:
                 else:
                     raise TypeError("Unknown role '%s'" % role)
 
-            self.thread.append(msg)
+            if insert:
+                self.thread.insert(insert, msg)
+            else:
+                self.thread.append(msg)
+
+    def insert(self, index, *messages):
+        """ Inserts messages at a given index in the Thread """
+
+        self.feed(
+            insert=True,
+            *messages
+        )
 
     @property
     def messages(self):
         """ Returns a JSON-safe list of all messages in this thread """
+
         return [ msg.obj for msg in self.thread ]
 
-    def run(self, feed=True):
-        """ Executes the current thread and get a response. If `feed` is
-        True, it will automatically save the response to the thread. """
+    def run(self, *append_messages, feed=True):
+        """ Executes the current Thread and get a response. If `feed` is
+        True, it will automatically save the response to the Thread.
+
+        You can provide *messages that will only apply to this run(), and
+        won't be stored in the Thread. """
+
         messages = self.messages
+        append_messages = [ msg.obj for msg in append_messages ]
 
         response_obj = openai.ChatCompletion.create(
             model="gpt-3.5-turbo",
-            messages=messages
+            messages=messages + append_messages
         )
 
         response = Response(response_obj)
@@ -103,7 +130,7 @@ class Thread:
 
     def moderate(self, prompt):
         """ Validate a prompt to ensure it's safe for OpenAI's policies """
-        
+
         response = openai.Moderation.create(
             input=prompt
         )
